=======
Credits
=======

Development Lead
----------------

* `Lauréline Guérin / @zebuline <https://github.com/zebuline>`_ <laureline.guerin /at/ people-doc.com>

Contributors (by alphabetic order)
----------------------------------

- `@ewjoachim <https://github.com/ewjoachim>`_
